ziggy.hdmc.hadoop_config

Package ziggy :: Package hdmc :: Module hadoop_config |
[hide private]
[frames] | no frames]

# Source Code for Module ziggy.hdmc.hadoop_config

    1  hadoop_home='/usr/local/hadoop/'
    2  hadoop='/usr/local/hadoop/bin/hadoop'
    3  hadoop_streaming='/usr/local/hadoop/contrib/streaming/hadoop-0.20.2-streaming.jar'
    4  num_map_tasks=20
    5  shared_tmp_space='/usr/local/hadoop/user-tmp'
    6